@@ -141,7 +141,7 @@ extern struct wrttmp mywrt;
 	    if (mywrt.wrt_last[0] == '\0')
 	    {
 		printf("No previous write or telegram.  Can't repeat\n");
-		log("FAIL: no previous");
+		wrtlog("FAIL: no previous");
 		done(1);
 	    }
 	    strncpy(hisname,mywrt.wrt_last,UT_NAMESIZE);
@@ -170,13 +170,13 @@ extern struct wrttmp mywrt;
 	    else if (rc == 1)
 	    {
 		printf("No such tty\n");
-		log("FAIL: no such tty");
+		wrtlog("FAIL: no such tty");
 		done(1);
 	    }
 	    else
 	    {
 		printf("%s not logged onto %s\n",hisname,histty);
-		log("FAIL: not on tty");
+		wrtlog("FAIL: not on tty");
 		done(1);
 	    }
 	}
@@ -253,7 +253,7 @@ long tmppos;
 	/* didn't find any matches, trouble */
 	printf("%s is not logged on\n",hisname);
 	{
-	    log("FAIL: not on");
+	    wrtlog("FAIL: not on");
 	    done(1);
 	}
     }
@@ -300,7 +300,7 @@ struct utmp *ut;
 	if (*ut->ut_name == '\0')
 	{
 	    printf("No one logged onto %s\n",histty);
-	    log("FAIL: empty tty");
+	    wrtlog("FAIL: empty tty");
 	    done(1);
 	}
 	strncpy(hisname, ut->ut_name, UT_NAMESIZE);
@@ -344,7 +344,7 @@ int slot;
     }
 
     printf("You are not being written\n");
-    log("FAIL: not written");
+    wrtlog("FAIL: not written");
     done(0);
 }
 
@@ -444,14 +444,14 @@ long tmppos;
 	{
 	    printf("Sorry, no helpers are available right now.\n");
 	    if (f_nohelp) type_help(f_nohelp);
-	    log("FAIL: no helpers");
+	    wrtlog("FAIL: no helpers");
 	}
 	else
 	{
 	    printf("Sorry, all helpers currently available are busy.\n");
 	    if (f_nohelp) type_help(f_nohelp);
 	    printf("Try again later...\n");
-	    log("FAIL: help busy");
+	    wrtlog("FAIL: help busy");
 	}
 	done(0);
     }
