@@ -26,7 +26,7 @@
  *   Grexers by the thousands have served (willy-nilly) as beta testers.
  */
 
-char *version= "2.54";
+char *version= "2.55";
 
 #include "write.h"
 #include <sys/resource.h>
@@ -69,7 +69,7 @@ bool insys= FALSE;		/* Am I in | or & escape? */
 
 bool readyn(void);
 void type_help(char *file);
-void log(char *outcome);
+void wrtlog(char *outcome);
 
 
 main(int argc, char **argv)
@@ -145,7 +145,7 @@ int tmp;
     {
 	if (telegram) putchar('\n');
 	printf("Permission denied: %s is not accepting messages\n",hisname);
-	log("FAIL: denied");
+	wrtlog("FAIL: denied");
 	done(1);
     }
 
@@ -176,7 +176,7 @@ int tmp;
 	fflush(stdout);
 	if (!readyn())
 	{
-		log("ABANDON: interupting");
+		wrtlog("ABANDON: interupting");
 		done(1);
 	}
     }
@@ -193,14 +193,14 @@ int tmp;
 	if (!(hiswrt.wrt_telpref & (TELPREF_WRITE|TELPREF_TEL)) )
 	{
 	    if (!no_switch) printf("Try the \042talk\042 command.\n");
-	    log("FAIL: can't switch - talk only");
+	    wrtlog("FAIL: can't switch - talk only");
 	    done(1);
 	}
 	if (no_switch || file_input)
 	{
 	    if (!no_switch) printf("Try the \042write\042 command "
 				   "(with no input redirection).\n");
-	    log("FAIL: can't switch");
+	    wrtlog("FAIL: can't switch");
 	    done(1);
 	}
 	else
@@ -211,7 +211,7 @@ int tmp;
 	    {
 		if (!am_root)
 		{
-		    log("ABANDON: won't switch");
+		    wrtlog("ABANDON: won't switch");
 		    done(1);
 		}
 	    }
@@ -273,7 +273,7 @@ int tmp;
 	open_record();
 
     open_hist();
-    log(rec_only?"POSTPONED":"OK");
+    wrtlog(rec_only?"POSTPONED":"OK");
 
     /* Now that his terminal and the wrttmp file are open, abandon superuser */
     setuid(getuid());
@@ -366,7 +366,7 @@ int ch;
 /* LOG - This logs a write execution.
  */
 
-void log(char *outcome)
+void wrtlog(char *outcome)
 {
 FILE *fp;
 time_t tock;
